
import QtQuick 1.1
import Process 0.1
import "."
import "../Television"
import ".."
import "../Globals.js" as Globals
import FileIO 1.0
import VLCVideo 1.0

Item {
    id: root
    property QtObject filteredCountryList
    property string tuner_id: tv.tunerType
    property variant scanner: serialScanner
    property bool isSetupWizard: false
    property bool isActive: (main.state === "DiagnosticState" && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0) || root.isSetupWizard
    property string cursorState: "setup" // setup or next

    anchors.fill: parent
    width: 1166
    height: 568

    Connections {
        target: root.isActive && !setupScanDialog.visible && !root.scanner.scanning && !countryListPopup.visible ? keymapper : null

        onBackPressed: {
            main.debugKeys("backPressed", "DiagnosticsTVSetup")
            diagnostics_screen.item.unselectScreen()
        }
    }

    function startScan() {
        tv.channelList.clearChannels()
        dciScanStart(countryListPopup.selectedData.countryId, digitalButton.isDown, analogButton.isDown, cableAntToggle.value)
    }

    Component.onCompleted: {
        if(!tuner_id) {
            print("no tuner installed")
            noTuner.showWithTimeout(10)
        }

        if (!serialTuner.initialized) {
            notYetInitializedMessage.show()
        }

        print("tuner type:" + tuner_id)
    }

    onTuner_idChanged: {
        filterCountries(tuner_id)
        // force re-selection of analog standard
        countryListPopup.currentIndexChanged()
    }

    function copyListModel(srcModel, destModel) {
        destModel.clear()
        for (var i = 0; i < srcModel.count; i++) {
            destModel.append(srcModel.get(i))
        }
    }

    function dciScanStart(countryCode, scanDigital, scanAnalog, cable) {
        root.scanner = serialScanner

        var atvMode = cable ? 1 : 0
        var scanDvbc = false
        if (serialTuner.cardModel === "TM017" && scanDigital && cable === true) {
            scanDvbc = true
        }

        serialScanner.startScan(countryCode, scanDigital, scanAnalog, atvMode, scanDvbc)
    }

    function stopScan() {
        root.scanner.stopScan()
    }

    function filterCountriesDCI() {
        copyListModel(tv_country_codes_pristine, tv_country_codes)
        var model = tv_country_codes
        for (var i = model.count - 1; i >= 0; i--) {
                var country = model.get(i).label
                if (model.get(i).countryId < 0 ) {
                    model.remove(i)
                } else if (model.get(i).cardModel.indexOf(serialTuner.cardModel) === -1) {
                    model.remove(i)
                } else if (model.get(i).tuner !== "DVB" && digitalButton.isDown && cableAntToggle.value === true) {
                    model.remove(i)
                }
        }
        return model
    }

    function filterCountries(tuner) {
        var origCode = tv_country_codes.get(countryListPopup.currentIndex).code
        var newModel
        if (tuner === "DCI") {
            newModel = filterCountriesDCI()
        }

        root.filteredCountryList = newModel
        countryListPopup.model = newModel
        countryListPopup.currentIndex = tv_country_codes.findIndexByCode(origCode)
    }

    Rectangle {
        id: channelListBox

        color: "lightgray"
        width: 725
        height: 460
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: -mode.width/2
        anchors.top: rightControlArea.top

        Item {
            id: dataArrows

            width: 40
            height: parent.height

            anchors { top: parent.top; right: parent.right ; rightMargin: Qt.application.layoutDirection === Qt.RightToLeft ? -20 : -5 }
            Image {
                id: dataUpArrow
                visible: !channelList.atYBeginning
                source: "../graphics/Swipe_Arrows_Left.png"
                rotation: 90
                anchors { top: parent.top; topMargin: 35; right: parent.right }
            }
            Image {
                id: dataDownArrow
                visible: !channelList.atYEnd
                source: "../graphics/Swipe_Arrows_Right.png"
                rotation: 90
                anchors { bottom: parent.bottom; bottomMargin: 35; right: parent.right }
            }
        }
        VLCSurface {
            id: onScreenDisplay
            visible: serialTuner.scanning
            player: tv.player
            aspect: tv.aspect
            playing: 1
            width: parent.width * 0.9
            height: width/tv.aspect - 100
            anchors.centerIn: parent
            onPlayingChanged: tv.on = playing
            z: 1000
        }

        GridView {
            id: channelList

            property int imageClickIndex

            clip: true
            anchors.fill: parent
            anchors {
                leftMargin: 30
                topMargin: 10
                bottomMargin: 5
                rightMargin: 5
            }
            model: tv.channelList.channels
            cellWidth: 160
            cellHeight: 150

            delegate: Component {
                Item {
                    width: 160; height: 150
                    Item {
                        width: 110; height: 135
                        anchors { left: parent.left; top: parent.top }

                        Rectangle{
                            id: iconBg
                            color: "white"
                            height: 110; width: 110

                            Image {
                                id: iconImage
                                anchors.horizontalCenter: parent.horizontalCenter
                                anchors.top: parent.top
                                source: icon ? "../graphics/TvIcons/default/channelIcons/" + icon : "../graphics/TvIcons/default/channelIcons/tv_default.png"
//                                MouseArea {
//                                    anchors.fill: parent
//                                    onClicked: {
//                                        channelList.imageClickIndex = index
//                                        iconSelector.show()
//                                    }
//                                }
                            }
                        }

                        Text {
                            text: {
                                if (name === "AUX") // special case
                                    return "AUX"

                                if (number && name && number != name) {
                                    return Globals.truncate(name, 23) + " " + number
                                } else if (name) {
                                    return Globals.truncate(name, 26)
                                } else if (number) {
                                    return number
                                } else {
                                    return ""
                                }
                            }
                            font.bold: true
                            font.pointSize: 12
                            anchors { horizontalCenter: iconBg.horizontalCenter; top: iconBg.bottom; topMargin: 0 }
                            verticalAlignment: Text.AlignVCenter
                            width: 110
                            horizontalAlignment: Text.AlignHCenter
                            lineHeight: 0.85
                            wrapMode: Text.WrapAnywhere
                        }
                    }
                }
            }
        }
    }

    Text {
        id: instructionalText
        text: qsTranslate("DiagnosticsTVSetup", "NOTE: If you are having trouble receiving channels after scanning, or having issues with channel clarity after confirming good connections to this machine, please contact your TV provider to ensure proper scan settings and signal strength.") + application.emptyString
        width: channelListBox.width
        wrapMode: Text.WordWrap
        anchors.left: channelListBox.left
        anchors.top: channelListBox.bottom
        anchors.topMargin: 5
        font { pixelSize: 18; bold: true }
    }

    Rectangle {
        id: rightControlArea

        width: 280
        height: 460
        color: "#7f8082"
        anchors { left: channelListBox.right; top: parent.top; topMargin: 98 }
    }

    ListView{
        id: mode
        anchors {
            top: rightControlArea.top; topMargin: 10
            left: rightControlArea.left
        }
        width: 280
        height: 700
        spacing: 5
        z: 100
        model: controlList.model
        snapMode: ListView.SnapToItem
        interactive: false
        highlightRangeMode: ListView.ApplyRange
        preferredHighlightBegin: height/2 - 30
        preferredHighlightEnd: height/2 + 30
        highlightMoveSpeed: 10000
        currentIndex: controlList.curIndex
        highlight: Component {
            BorderImage {
                id: selectionCursor
                visible: main.isTft && controlList.listening
                border { left: 70; top: 5; bottom: 5; right: 70 }
                source: "../graphics/tft/maintenance_menus_cursor2.png"
                width: mode.currentItem ? mode.currentItem.navCursorWidth : 0
                height: 71
                horizontalTileMode: BorderImage.Stretch
            }
        }
    }

    MessagePopup {
        id: noTuner
        message: qsTr("No Tuner Installed.") + application.emptyString
    }

    Connections {
        target: main.isTft && !dialogManager.anyAreBlockingKeys && root.visible && root.isActive && root.cursorState === "next" ? keymapper : null

        onUpButtonPressed: {
            main.debugKeys("upButtonPressed", "DiagnosticsTVSetup")
            controlList.curIndex = controlList.findLastValidIndex()
            cursorState = "setup"
        }
        onDownButtonPressed: {
            main.debugKeys("downButtonPressed", "DiagnosticsTVSetup")
            controlList.curIndex = controlList.findFirstValidIndex()
            cursorState = "setup"
        }
        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "DiagnosticsTVSetup")
            setupWizard.changeState()
        }
    }

    KeyedControlList {
        id: controlList
        listening: main.isTft && !dialogManager.anyAreBlockingKeys && root.visible && root.isActive && !setupScanDialog.visible && !root.scanner.scanning && !countryListPopup.visible && root.cursorState === "setup"
        listView: mode
        width: mode.width
        curIndex: 0

        edgeBehavior: isSetupWizard ? "emit" : "wrap"
        onFirstExited: root.cursorState = "next"
        onLastExited: root.cursorState = "next"

        InlineButton {
            id: startScan

            enabled: digitalButton.isDown || analogButton.isDown
            label: qsTr("Begin Channel Scan") + application.emptyString
            showImage: true
            width: 200
            labelWidth: 130
            height: 71
            navCursorWidth: mode.width+20
            font { pixelSize: 18; bold: true }

            onPressed: {
                setupScanDialog.show()
            }
        }
    }

    // When scan is complete, show how many services were found.
    Text {
        id: channelsFoundText
        text: {
            if (root.scanner.scanning)
                return ""
            else if (channelList.count > 0)
                return qsTr("Number of Channels:") + " " + channelList.count + application.emptyString
            else
                return qsTr("No Channels Configured") + application.emptyString
        }
        anchors.bottom: channelListBox.top
        anchors.bottomMargin: 15
        anchors.left: channelListBox.left
        font { pixelSize: 18; bold: true }
    }

    ModalDialog {
        id: setupScanDialog
        dismissable: true

        onDismissed: {
            setupScanDialog.hide()
        }

        onVisibleChanged: {
            if (!visible)
                countryListPopup.close()
        }

        BorderImage {   // pop-up dialog background
            id: border2

            x: 332
            y: 101
            width: 800
            height: 650
            source: "../graphics/Pop_Up_Lrg_Grey.png"
            border { top: 152; bottom: 165; left: 145; right: 144 }
            Text {
                id: scanHeader
                width: 501
                height: 99
                color: "#ffffff"
                text: qsTr("Channel Scan") + application.emptyString
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: parent.top
                anchors.topMargin: 35
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.pixelSize: 40
            }

            ListView{
                id: scanControls
                anchors {
                    top: scanHeader.bottom
                    topMargin: -20
                    horizontalCenter: parent.horizontalCenter
                }
                width: 280
                height: 700
                spacing: 5
                z: 100
                model: tvSetupControlList.model
                snapMode: ListView.SnapToItem
                interactive: false
                highlightRangeMode: ListView.ApplyRange
                preferredHighlightBegin: height/2 - 30
                preferredHighlightEnd: height/2 + 30
                highlightMoveSpeed: 10000
                currentIndex: tvSetupControlList.curIndex
                onVisibleChanged: if (visible) tvSetupControlList.curIndex = 0
                highlight: Component {
                    BorderImage {
                        id: selectionCursor
                        visible: main.isTft && tvSetupControlList.listening
                        border { left: 70; top: 5; bottom: 5; right: 70 }
                        source: "../graphics/tft/maintenance_menus_cursor2.png"
                        width: scanControls.currentItem ? scanControls.currentItem.navCursorWidth : 0
                        height: 71
                        horizontalTileMode: BorderImage.Stretch
                    }
                }
            }
            KeyedControlList {
                id: tvSetupControlList
                listening: main.isTft && setupScanDialog.visible && root.isActive && !root.scanner.scanning && !countryListPopup.visible && root.cursorState === "setup"
                listView: scanControls
                width: scanControls.width
                curIndex: 0

                edgeBehavior: "wrap"
                Item {
                    id: analogItem
                    height: 71
                    width: scanControls.width
                    x: 30

                    // attributes needed to be used in a KeyedControlList
                    property bool selected: false
                    property int navCursorWidth: analogItem.width+20
                    function leftPressed() { analogButton.setDown(true) }
                    function rightPressed() { analogButton.setDown(true) }
                    function enterPressed() { analogButton.setDown(true) }
                    ImageButton {
                        id: analogButton

                        enabled: true

                        //                label: qsTr("Analog") + application.emptyString
                        //                label_color: "black"
                        //                label_under: true
                        toggle: true
                        radioGroup: [analogButton, digitalButton]

                        upimage: "graphics/205/SM_Button_Up.png"
                        downimage: upimage
                        icon: isDown ? "graphics/205/IPOD_Checkmark.png" : ""
                    }
                    Text{
                        id: analogLabel
                        text: qsTr("Analog") + application.emptyString
                        anchors.left: analogButton.right
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.verticalCenterOffset: -8
                        color: "black"
                        font { pixelSize: 18; bold: true }
                    }
                }

                Item {
                    id: digitalItem
                    height: 71
                    width: scanControls.width
                    x: 30

                    // attributes needed to be used in a KeyedControlList
                    property bool selected: false
                    property int navCursorWidth: digitalItem.width+20
                    function leftPressed() { digitalButton.setDown(true) }
                    function rightPressed() { digitalButton.setDown(true) }
                    function enterPressed() { digitalButton.setDown(true) }

                    ImageButton {
                        id: digitalButton

                        enabled: true
                        isDown: true
                        //                label: qsTr("Digital") + application.emptyString
                        //                label_color: "black"
                        //                label_under: true
                        toggle: true
                        radioGroup: [analogButton, digitalButton]

                        upimage: "graphics/205/SM_Button_Up.png"
                        downimage: upimage
                        icon: isDown ? "graphics/205/IPOD_Checkmark.png" : ""
                    }

                    Text{
                        id: digitalLabel
                        text: qsTr("Digital") + application.emptyString
                        anchors.left: digitalButton.right
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.verticalCenterOffset: -8
                        color: "black"
                        font { pixelSize: 18; bold: true }
                    }
                }

                ToggleButtonLabeled {
                    id: cableAntToggle

                    anchors.horizontalCenter: parent.horizontalCenter
                    anchors.horizontalCenterOffset: -40
                    pos0label: qsTr("Antenna") + application.emptyString
                    pos1label: qsTr("Cable") + application.emptyString
                    pos0image: "graphics/tft/maintenance_toggle.png"
                    pos0image_disabled: "graphics/tft/maintenance_toggle_GRAYED.png"
                    pos1image: "graphics/tft/maintenance_toggle_OFF.png"
                    pos1image_disabled: "graphics/tft/maintenance_toggle_OFF_GRAYED.png"
                    labelcolor: "black"
                    highlightcolor: "black"
                    posFont { pixelSize: 18; bold: true }
                    value: false // Set default to Antenna for DCI tuner
                    navCursorWidth: scanControls.width+20
                    enabled: {
                        if (root.tuner_id === "DVB" && digitalButton.isDown) {
                            // Don't allow cable scans on h830 tuner - because DVB-C is not supported
                            return false
                        } else if (root.tuner_id === "DCI" && serialTuner.cardModel !== "TM017" && digitalButton.isDown) {
                            // Only TM017 model of DCI tuner supports DVB-C scanning
                            return false
                        }
                        return true
                    }
                    disabled: !enabled
                    onValueChanged: {
                        // Repopulate valid country list for DCI tuner
                        if (tuner_id === "DCI") {
                            filterCountries(tuner_id)
                        }
                    }

                    Connections {
                        target: digitalButton
                        onIsDownChanged: {
                            if(digitalButton.isDown && (tuner_id == "DVB")) {
                                cableAntToggle.value = false
                            } else if (digitalButton.isDown && tuner_id === "DCI" && serialTuner.cardModel !== "TM017") {
                                cableAntToggle.value = false
                            }

                            // Repopulate valid country list for DCI tuner
                            if (tuner_id === "DCI") {
                                filterCountries(tuner_id)
                            }
                        }
                    }
                }

                Item {
                    id: countrySelect
                    width: scanControls.width
                    height: 71

                    // properties needed to be used in a KeyedControlList
                    property int navCursorWidth: scanControls.width+20
                    property bool selected: false
                    function enterPressed() { countryListPopup.visible = true }
                    function leftPressed() { countryListPopup.decrementCurrentIndex() }
                    function rightPressed() { countryListPopup.incrementCurrentIndex() }

                    Rectangle {
                        color: "#5f6062"
                        radius: 10
                        width: parent.width - 35
                        height: 30
                        x: 25
                        anchors.verticalCenter: parent.verticalCenter
                        Text {
                            id: countryValue
                            text: qsTranslate("TelevisionRegionList", countryListPopup.selectedData ? countryListPopup.selectedData.label : "") + application.emptyString
                            anchors.left: parent.left
                            anchors.leftMargin: 15
                            anchors.verticalCenter: parent.verticalCenter
                            font.bold: true
                        }
                        MouseArea {
                            anchors.fill: parent
                            onClicked: {
                                countryListPopup.visible = true
                            }
                        }
                    }

                }
                InlineButton {
                    id: beginScanButton

                    enabled: digitalButton.isDown || analogButton.isDown
                    label: qsTr("Begin Channel Scan") + application.emptyString
                    showImage: true
                    width: 200
                    labelWidth: 130
                    height: 71
                    navCursorWidth: mode.width+20
                    font { pixelSize: 18; bold: true }

                    onPressed: {
                        setupScanDialog.hide()
                        root.startScan()
                    }
                }
            }

            Text {
                visible: main.isTft
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 40
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.horizontalCenterOffset: -10
                color: "#ffffff"
                font { bold: true; pixelSize: 24 }
                text: qsTr("press BACK to abort") + application.emptyString
            }

            CountryListPopup {
                id: countryListPopup
                model: filteredCountryList
                modelTranslationContext: "TelevisionRegionList"
                anchors {
                    right: parent.right
                    top: parent.top
                    topMargin: -20
                }
            }

        }
        Component.onCompleted: hide()
        onTimedOut: hide()
    }
    MessagePopup {
        id: startScanDialog
        message: qsTr("Starting Scan...") + application.emptyString
        dismissable: false
        Component.onCompleted: hide()
    }

    ModalDialog {
        id: scanningDialog
        dismissable: true

        onDismissed: {
            root.stopScan()
        }

        BorderImage {   // pop-up dialog background
            id: border

            x: 332
            y: 161
            width: 800
            height: 390
            source: "../graphics/Pop_Up_Lrg_Grey.png"
            border { top: 152; bottom: 165; left: 145; right: 144 }
            Text {
                id: warningText
                width: 501
                height: 99
                color: "#ffffff"
                text: qsTr("Scanning in progress") + application.emptyString
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: parent.top
                anchors.topMargin: 35
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.pixelSize: 40
            }

            Text {
                visible: main.isTft
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 40
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.horizontalCenterOffset: -10
                color: "#ffffff"
                font { bold: true; pixelSize: 24 }
                text: qsTr("press BACK to abort") + application.emptyString
            }

        }
        Component.onCompleted: hide()

        onTimedOut: {
            hide()
            miniScanningDialog.show()
        }
    }
    MessageBanner {
        id: miniScanningDialog

        message: qsTr("Scanning in progress") + " " + qsTr("press BACK to abort") + application.emptyString
        onDismissed: {
            root.stopScan()
        }

        visible: true
        z: 10000
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: 100
        y:1
        dismissable: true
        dismissAnywhere: true
        isTransparent: true
    }

    MessagePopup {
        id: finishingScanPopup
        message: qsTr("Finishing scan...") + application.emptyString
        visible: root.scanner.scanning && root.scanner.aborted
    }

    TelevisionRegionList {
        id: tv_country_codes
    }

    TelevisionRegionList {
        id: tv_country_codes_pristine
    }

    TelevisionScanSerial {
        id: serialScanner

        onScanInitializing: {
            startScanDialog.show()
        }

        onScanStarted: {
            startScanDialog.hide()
            scanningDialog.show()
            scanningDialog.startTimeout(5)
            tv.mrl = tv.channelList.getOnscreenDisplayMrl(countryListPopup.selectedData.countryId)
        }

        onScanComplete: {
            tv.mrl = ""
            scanningDialog.hide()
            miniScanningDialog.hide()
        }
    }

    ImageButton { id: nextButton
        downimage: "graphics/setup/Start_Button_Down.png"
        upimage: "graphics/setup/Start_Button.png"

        // TFT items are responsible for adding their own next button
        visible: root.isSetupWizard && main.isTft
        label: qsTr("NEXT") + application.emptyString
        label_color: "black"
        label_under: true
        fontsize: 18
        z: 9999

        anchors {
            bottom: parent.bottom ; bottomMargin: 25
            right: parent.right ; rightMargin: 46
        }

        onClicked: {
            setupWizard.changeState()
        }
    }

    Image {
        source: "../graphics/tft/NAV_selector_2.png"
        visible: main.isTft && root.isActive && cursorState === "next"
        anchors.centerIn: nextButton
        z: nextButton.z - 1
    }

    MessagePopup {
        id: notYetInitializedMessage
        message: qsTr("Tuner not initialized") + application.emptyString
        blockKeys: true
    }

}
