import QtQuick 1.1
import Settings 1.0

Item {
    id: root

    property string defaultLanguageDefault: "en"
    property bool metricUnitsDefault: false
    property int cooldownTimeDefault: 120 // 2 minutes
    property int workoutTimeMaxDefault: 60 // 60 minutes
    property bool saveWorkoutEnabledDefault: false
    property int workoutSetupTimeoutDefault: 45
    property int workoutMenuTimeoutDefault: 45
    property int workoutSummaryTimeoutDefault: 30
    property int screenSaveTimeoutDefault: 600 // 10 minutes
    property int sleepModeTimeoutDefault: 0 // 0 minutes
    property int dimDisplayTimeoutDefault: 600 // 10 minutes
    property bool contactHRPriorityDefault: true 
    property bool simulationModeDefault: false
    property bool showStimulusAreaDefault: false
    property bool netpulseEnabledDefault: false
    property bool browserEnabledDefault: false
    property bool disableNoPedalStopDefault: false
    property bool showCursorDefault: false
    property int systemVolumeDefault: 60
    property int lcdBrightnessDefault: 80
    property bool ignoreFaultsDefault: false
    property int resumeWorkoutTimeoutDefault:30 // 30 seconds
    property bool erpEnabledDefault: false
    property int erpTimeoutDefault: 1800 // 30 minutes
    property bool disableBuzzerDefault: false
    property string homeURLDefault: "http://software.truefitness.com/console_links/us"
    property string browserCountryCodeDefault: "us"
    property bool cabEnabledDefault: false
    property string cabSettingDefault: "STB_00"
    property bool en957EnabledDefault: false
    property bool touchJitterControlDefault: true
    property bool manufacturingTestModeEnabledDefault: false
    property bool setupWizardCompletedDefault: false

    property bool ppdEnabledDefault: true
    property int ppdTimer1Default: 60 //ppd timer 1 60 seconds
    property int ppdTimer2Default: 20 // ppd timer 2 20 seconds

    property int resumeWorkoutTimeoutDefault_ES900:0
    property int sleepModeTimeoutDefault_ES900: 1800 // 30 minutes
    property bool saveWorkoutEnabledDefault_ES900: true
    property int screenSaveTimeoutDefault_ES900: 600 // 10 minutes
    property int cooldownTimeDefault_ES900: 120 // 2 minutes
    property int workoutTimeMaxDefault_ES900: 99 // 99 minutes
    property bool tvNoFrameDropDefault: false
    property bool tvHwAccelDefault: false
    property bool loggingEnabledDefault: false
    property int brainboardDebugLogLevelDefault: 0
    property bool iptvEnabledDefault: false
    property bool modestyModeDefault: false
    property bool maxSpeedRegulatorEnabledDefault: false
    property int maxSpeedRegulatorValueDefault: 0
    property bool diagnosticsUploadEnabledDefault: true

    property string defaultLanguage: defaultLanguageDefault
    property bool metricUnits: metricUnitsDefault
    property int cooldownTime: cooldownTimeDefault
    property int workoutTimeMax: workoutTimeMaxDefault
    property bool saveWorkoutEnabled: saveWorkoutEnabledDefault
    property int workoutSetupTimeout: workoutSetupTimeoutDefault
    property int workoutMenuTimeout: workoutMenuTimeoutDefault
    property int workoutSummaryTimeout: workoutSummaryTimeoutDefault
    property int screenSaveTimeout: screenSaveTimeoutDefault
    property int dimDisplayTimeout: dimDisplayTimeoutDefault
    property int sleepModeTimeout: sleepModeTimeoutDefault
    property bool contactHRPriority: contactHRPriorityDefault
    property bool simulationMode: simulationModeDefault
    property bool showStimulusArea: showStimulusAreaDefault
    property bool netpulseEnabled: netpulseEnabledDefault
    property bool browserEnabled: browserEnabledDefault
    property bool disableNoPedalStop: disableNoPedalStopDefault
    property int systemVolume: systemVolumeDefault
    property int lcdBrightness: lcdBrightnessDefault
    property bool showCursor: showCursorDefault
    property bool ignoreFaults: ignoreFaultsDefault
    property int resumeWorkoutTimeout: resumeWorkoutTimeoutDefault
    property bool disableBuzzer: disableBuzzerDefault
    property bool ppdEnabled: ppdEnabledDefault    
    property int personPresentTimeout: ppdTimer1Default
    property int noUserDetectedDialogTimeout: ppdTimer2Default
    property bool tvNoFrameDrop: tvNoFrameDropDefault
    property bool tvHwAccel: tvHwAccelDefault
    property bool loggingEnabled: loggingEnabledDefault
    property int brainboardDebugLogLevel: brainboardDebugLogLevelDefault
    property bool iptvEnabled: iptvEnabledDefault
    property bool modestyMode: modestyModeDefault
    property bool en957Enabled: en957EnabledDefault
    property bool maxSpeedRegulatorEnabled: maxSpeedRegulatorEnabledDefault
    property int maxSpeedRegulatorValue: maxSpeedRegulatorEnabledDefault
    property bool touchJitterControl: touchJitterControlDefault
    property bool manufacturingTestModeEnabled: manufacturingTestModeEnabledDefault
    property bool setupWizardCompleted: setupWizardCompletedDefault
    property bool diagnosticsUploadEnabled: diagnosticsUploadEnabledDefault

    property bool erpEnabled: erpEnabledDefault
    property int erpTimeout: erpTimeoutDefault

    property string homeURL: homeURLDefault
    property string browserCountryCode: browserCountryCodeDefault

    property bool cabEnabled: cabEnabledDefault
    property string cabSetting: cabSettingDefault

    property bool loaded: false

    function getSetting(key, defval) {
        return settingsObj.getValue(key, defval)
    }

    function setSetting(key, value) {
        settingsObj.setValue(key,value)
    }

    function setDefaults() {
        defaultLanguage = defaultLanguageDefault
        metricUnits = metricUnitsDefault
        workoutSetupTimeout = workoutSetupTimeoutDefault
        workoutMenuTimeout = workoutMenuTimeoutDefault
        workoutSummaryTimeout = workoutSummaryTimeoutDefault
        contactHRPriority = contactHRPriorityDefault       
        simulationMode = simulationModeDefault
        showStimulusArea = showStimulusAreaDefault
        netpulseEnabled = netpulseEnabledDefault
        browserEnabled = browserEnabledDefault
        disableNoPedalStop = disableNoPedalStopDefault
        systemVolume = systemVolumeDefault
        showCursor = showCursorDefault
        lcdBrightness = lcdBrightnessDefault
        ignoreFaults = ignoreFaultsDefault
        personPresentTimeout = ppdTimer1Default
        noUserDetectedDialogTimeout = ppdTimer2Default
        ppdEnabled = ppdEnabledDefault
        tvNoFrameDrop = tvNoFrameDropDefault
        tvHwAccel = tvHwAccelDefault
        if(tv.tunerType === "ATSC")
            erpEnabled = false
        else
            erpEnabled = true
        iptvEnabled = iptvEnabledDefault
        modestyMode = modestyModeDefault
        erpTimeout = erpTimeoutDefault
        disableBuzzer = disableBuzzerDefault
        homeURL = homeURLDefault
        browserCountryCode = browserCountryCodeDefault
        loggingEnabled = loggingEnabledDefault
        brainboardDebugLogLevel = brainboardDebugLogLevelDefault
        cabEnabled = cabEnabledDefault
        cabSetting = cabSettingDefault
        en957Enabled = en957EnabledDefault
        maxSpeedRegulatorEnabled = maxSpeedRegulatorEnabledDefault
        maxSpeedRegulatorValue = maxSpeedRegulatorValueDefault
        touchJitterControl = touchJitterControlDefault
        manufacturingTestModeEnabled = manufacturingTestModeEnabledDefault
        setupWizardCompleted = setupWizardCompletedDefault
        diagnosticsUploadEnabled = diagnosticsUploadEnabledDefault
    }

    function setProductDependentDefaults(modelstring){
        if(modelstring === "TES900"){
            resumeWorkoutTimeout = resumeWorkoutTimeoutDefault_ES900
            sleepModeTimeout = sleepModeTimeoutDefault_ES900
            saveWorkoutEnabled = saveWorkoutEnabledDefault_ES900
            screenSaveTimeout = screenSaveTimeoutDefault_ES900
            dimDisplayTimeout = dimDisplayTimeoutDefault
            cooldownTime = cooldownTimeDefault_ES900
            workoutTimeMax = workoutTimeMaxDefault_ES900
        } else {
            resumeWorkoutTimeout = resumeWorkoutTimeoutDefault
            sleepModeTimeout = sleepModeTimeoutDefault
            saveWorkoutEnabled = saveWorkoutEnabledDefault
            screenSaveTimeout = screenSaveTimeoutDefault
            dimDisplayTimeout = dimDisplayTimeoutDefault
            cooldownTime = cooldownTimeDefault
            workoutTimeMax = workoutTimeMaxDefault

            // commercial product web browser: no links url by default for US
            browserEnabled = false
        }
    }

    function loadOptions() {
        if(loaded)
            return

        defaultLanguage = getSetting("defaultLanguage", root.defaultLanguageDefault)
        simulationMode = getSetting("simulationMode", simulationModeDefault)
        showStimulusArea = getSetting("showStimulusArea", showStimulusAreaDefault)

        if(getSetting("heartRatePriority", "contact") === "contact")
            contactHRPriority = 1
        else
            contactHRPriority = 0

        brainboard.setContactPriority(contactHRPriority)

        saveWorkoutEnabled = getSetting("saveworkout", saveWorkoutEnabledDefault)

        if(getSetting("measureUnits", "english") === "english")
            metricUnits = 0
        else
            metricUnits = 1

        cooldownTime = getSetting("cooltime", cooldownTimeDefault)
        workoutTimeMax = getSetting("workoutTimeMax", workoutTimeMaxDefault)
        workoutSetupTimeout = getSetting("workoutSetupTimeout", workoutSetupTimeoutDefault)
        personPresentTimeout = getSetting("personPresentTimeout", ppdTimer1Default)
        workoutMenuTimeout = getSetting("workoutMenuTimeout", workoutMenuTimeoutDefault)
        workoutSummaryTimeout = getSetting("workoutSummaryTimeout", workoutSummaryTimeoutDefault)
        screenSaveTimeout = getSetting("screenSaveTimeout", screenSaveTimeoutDefault)
        dimDisplayTimeout = getSetting("dimDisplayTimeout", dimDisplayTimeoutDefault)
        sleepModeTimeout = getSetting("sleepModeTimeout", sleepModeTimeoutDefault)
        netpulseEnabled = getSetting("netpulseEnabled", netpulseEnabledDefault)
        browserEnabled = getSetting("browserEnabled", browserEnabledDefault)
        disableNoPedalStop = getSetting("disableNoPedalStop", disableNoPedalStopDefault)
        systemVolume = getSetting("systemVolume", systemVolumeDefault)
        lcdBrightness = getSetting("lcdBrightness", lcdBrightnessDefault)
        showCursor = getSetting("showCursor", showCursorDefault)
        ignoreFaults = getSetting("ignoreFaults", ignoreFaultsDefault)
        noUserDetectedDialogTimeout = getSetting("noUserDetectedDialogTimeout",ppdTimer2Default)
        resumeWorkoutTimeout = getSetting("resumeWorkoutTimeout",resumeWorkoutTimeoutDefault)
        ppdEnabled = getSetting("ppdEnabled",ppdEnabledDefault)
        tvNoFrameDrop = getSetting("tvNoFrameDrop", tvNoFrameDropDefault)
        tvHwAccel =getSetting("tvHwAccel", tvHwAccelDefault)
        loggingEnabled = getSetting("loggingEnabled", loggingEnabledDefault)

        erpEnabled = getSetting("erpEnabled",erpEnabledDefault)
        erpTimeout = getSetting("erpTimeout",erpTimeoutDefault)
        disableBuzzer = getSetting("disableBuzzer", disableBuzzerDefault)
        homeURL = getSetting("homeURL", homeURLDefault)
        browserCountryCode = getSetting("browserCountryCode", browserCountryCodeDefault)
        brainboardDebugLogLevel = getSetting("brainboardDebugLogLevel", brainboardDebugLogLevelDefault)
        cabEnabled = getSetting("cabEnabled", cabEnabledDefault)
        cabSetting = getSetting("cabSetting", cabSettingDefault)
        iptvEnabled = getSetting("iptvEnabled", iptvEnabledDefault)
        modestyMode = getSetting("modestyMode", modestyMode)
        en957Enabled = getSetting("en957Enabled", en957EnabledDefault)
        maxSpeedRegulatorEnabled = getSetting("maxSpeedRegulatorEnabled", maxSpeedRegulatorEnabledDefault)
        maxSpeedRegulatorValue = getSetting("maxSpeedRegulatorValue", maxSpeedRegulatorValueDefault)
        touchJitterControl = getSetting("touchJitterControl", touchJitterControl)
        manufacturingTestModeEnabled = getSetting("manufacturingTestModeEnabled", manufacturingTestModeEnabledDefault)
        setupWizardCompleted = getSetting("setupWizardCompleted", setupWizardCompletedDefault)
	diagnosticsUploadEnabled = getSetting("diagnosticsUploadEnabled", diagnosticsUploadEnabledDefault)
        loaded = true
    }

    Settings {
        id: settingsObj
        filename: "~/.config/TrueFitness/Touch.conf"
    }

    Component.onCompleted: {
        loadOptions()
    }

    onSimulationModeChanged: {if(!loaded) return; settingsObj.setValue("simulationMode", simulationMode ? "1": "0")}
    onContactHRPriorityChanged: {if(!loaded) return; settingsObj.setValue("heartRatePriority", contactHRPriority ? "contact": "telemetry")}
    onSaveWorkoutEnabledChanged: {if(!loaded) return; settingsObj.setValue("saveworkout", saveWorkoutEnabled ? "1": "0")}
    onMetricUnitsChanged: {if(!loaded) return; settingsObj.setValue("measureUnits", metricUnits ? "metric": "english")}
    onDefaultLanguageChanged: {if(!loaded) return; settingsObj.setValue("defaultLanguage", defaultLanguage)}
    onCooldownTimeChanged: {if(!loaded) return; settingsObj.setValue("cooltime", cooldownTime)}
    onWorkoutTimeMaxChanged: {if(!loaded) return; settingsObj.setValue("workoutTimeMax", workoutTimeMax)}
    onWorkoutSetupTimeoutChanged: {if(!loaded) return; settingsObj.setValue("workoutSetupTimeout", workoutSetupTimeout)}
    onPersonPresentTimeoutChanged: {if(!loaded) return; settingsObj.setValue("personPresentTimeout", personPresentTimeout)}
    onWorkoutMenuTimeoutChanged: {if(!loaded) return; settingsObj.setValue("workoutMenuTimeout", workoutMenuTimeout)}
    onWorkoutSummaryTimeoutChanged: {if(!loaded) return; settingsObj.setValue("workoutSummaryTimeout", workoutSummaryTimeout)}
    onScreenSaveTimeoutChanged: {if(!loaded) return; settingsObj.setValue("screenSaveTimeout", screenSaveTimeout)}
    onDimDisplayTimeoutChanged: {if(!loaded) return; settingsObj.setValue("dimDisplayTimeout",dimDisplayTimeout)}
    onSleepModeTimeoutChanged: {if(!loaded) return; settingsObj.setValue("sleepModeTimeout", sleepModeTimeout)}
    onShowStimulusAreaChanged: {if(!loaded) return; settingsObj.setValue("showStimulusArea",showStimulusArea ? "1" : "0")}
    onNetpulseEnabledChanged: {if(!loaded) return; settingsObj.setValue("netpulseEnabled",netpulseEnabled ? "1" : "0")}
    onBrowserEnabledChanged:  {if(!loaded) return; settingsObj.setValue("browserEnabled",browserEnabled ? "1" : "0")}
    onDisableNoPedalStopChanged: { if(!loaded) return; settingsObj.setValue("disableNoPedalStop", disableNoPedalStop ? "1" : "0" ) }
    onSystemVolumeChanged: { if(!loaded) return; settingsObj.setValue("systemVolume", systemVolume); amixer.setVolume(systemVolume) }
    onLcdBrightnessChanged: { if(!loaded) return; settingsObj.setValue("lcdBrightness", lcdBrightness)}
    onShowCursorChanged: { if(!loaded) return; settingsObj.setValue("showCursor", showCursor ? "1" : "0" ) }
    onIgnoreFaultsChanged: { if(!loaded) return; settingsObj.setValue("ignoreFaults", ignoreFaults ? "1" : "0" ) }
    onNoUserDetectedDialogTimeoutChanged: { if(!loaded) return; settingsObj.setValue("noUserDetectedDialogTimeout", noUserDetectedDialogTimeout)}
    onResumeWorkoutTimeoutChanged: { if(!loaded) return; settingsObj.setValue("resumeWorkoutTimeout", resumeWorkoutTimeout)}
    onPpdEnabledChanged: { if(!loaded) return; settingsObj.setValue("ppdEnabled", ppdEnabled ? "1" : "0") }
    onTvNoFrameDropChanged: { if(!loaded) return; settingsObj.setValue("tvNoFrameDrop", tvNoFrameDrop ? "1" : "0") }
    onTvHwAccelChanged: { if(!loaded) return; settingsObj.setValue("tvHwAccel", tvHwAccel? "1" : "0") }
    onErpEnabledChanged: { if(!loaded) return; settingsObj.setValue("erpEnabled", erpEnabled ? "1" : "0") }
    onErpTimeoutChanged: { if(!loaded) return; settingsObj.setValue("erpTimeout",erpTimeout)}
    onDisableBuzzerChanged: { if(!loaded) return; settingsObj.setValue("disableBuzzer", disableBuzzer ? "1" : "0") }
    onHomeURLChanged: { if(!loaded) return; settingsObj.setValue("homeURL",homeURL)}
    onBrowserCountryCodeChanged: { if(!loaded) return; settingsObj.setValue("browserCountryCode",browserCountryCode)}
    onLoggingEnabledChanged: { if(!loaded) return; settingsObj.setValue("loggingEnabled", loggingEnabled ? "1" : "0") }
    onBrainboardDebugLogLevelChanged: { if(!loaded) return; settingsObj.setValue("brainboardDebugLogLevel", brainboardDebugLogLevel)}
    onCabEnabledChanged: { if(!loaded) return; settingsObj.setValue("cabEnabled", cabEnabled ? "1" : "0")}
    onCabSettingChanged: { if(!loaded) return; settingsObj.setValue("cabSetting", cabSetting)}
    onIptvEnabledChanged: { if(!loaded) return; settingsObj.setValue("iptvEnabled", iptvEnabled)}
    onModestyModeChanged: { if(!loaded) return; settingsObj.setValue("modestyMode", modestyMode)}
    onEn957EnabledChanged: { if(!loaded) return; settingsObj.setValue("en957Enabled", en957Enabled ? "1" : "0")}
    onMaxSpeedRegulatorEnabledChanged: { if(!loaded) return; settingsObj.setValue("maxSpeedRegulatorEnabled", maxSpeedRegulatorEnabled ? "1" : "0")}
    onMaxSpeedRegulatorValueChanged: { if(!loaded) return; settingsObj.setValue("maxSpeedRegulatorValue",maxSpeedRegulatorValue)}
    onTouchJitterControlChanged: {if(!loaded) return; settingsObj.setValue("touchJitterControl", touchJitterControl)}
    onManufacturingTestModeEnabledChanged: {if(!loaded) return; settingsObj.setValue("manufacturingTestModeEnabled", manufacturingTestModeEnabled)}
    onSetupWizardCompletedChanged: {if (!loaded) { return; } settingsObj.setValue("setupWizardCompleted", setupWizardCompleted) }
    onDiagnosticsUploadEnabledChanged: {if (!loaded) { return; } settingsObj.setValue("diagnosticsUploadEnabled", diagnosticsUploadEnabled) }
}

