import QtQuick 1.1
import Process 0.1
import SerialTuner 1.0
import ".."

Item {
    id: root

    property bool scanning: serialTuner.scanning
    property real progress: 0
    property alias channels: scanServices
    property bool debug: false
    property bool aborted: false

    signal scanInitializing()
    signal scanStarted()
    signal scanComplete()
    signal channelFound(variant chandata)

    function computeTvMode(scanDtv, scanAtv, atvMode) {
        if (scanDtv) {
            return 2
        } else {
            return atvMode
        }
    }

    function startScan(countryCode, scanDtv, scanAtv, atvMode, scanDvbc) {
        root.aborted = false
        if (!serialTuner.initialized) {
            return
        }

        scanServices.clear()

        var tvMode = computeTvMode(scanDtv, scanAtv, atvMode)
        serialTuner.startScan(countryCode, tvMode, scanDvbc)
    }

    function stopScan() {
        root.aborted = true
        serialTuner.abortScan()
    }

    function debugPrint(string) {
        if(root.debug)
            print(string)
    }

    Connections {
        target: serialTuner

        onScanStateChanged: {
            switch (serialTuner.scanState) {
                case SerialTuner.SCAN_INITIALIZING: {
                    console.log("SerialTuner: Scan Initializing")
                    root.scanInitializing()
                    break;
                }
                case SerialTuner.SCAN_SCANNING: {
                    console.log("SerialTuner: Scan Scanning")
                    root.scanStarted()
                    break;
                }
                case SerialTuner.SCAN_ABORTED: {
                    console.log("SerialTuner: Scan Aborted")
                    break;
                }
                case SerialTuner.SCAN_ENDED: {
                    console.log("SerialTuner: Scan Ended")
                    break;
                }
            }
        }

        onScanComplete: {
            root.scanComplete()
        }
    }

    ListModel {
        id: scanServices
    }

}
